import React, {Component} from 'react';
import {connect} from 'react-redux'
import Header from './header/Header'
import {buildUrlParams} from "../utils/encoders";
import mapDispatchToProps from '../dispatchers/routingInfoDispatcher'
import {withRouter} from "react-router-dom";
import {DialogContainer} from "./dialog/Dialog";
import {parse} from "query-string";


class ContentWrapper extends Component {
    componentDidMount() {
        const urlParams = buildUrlParams(this.props.match, this.props.location, window.location.href);
        this.props.updateUrlParams(urlParams);
    }

    UNSAFE_componentWillReceiveProps(nextProps) {
        if (!this.props.wizard) return;
        const {routingInfo} = this.props;
        if (routingInfo) {
            if (routingInfo.href && routingInfo.href !== window.location.href) {
                this.props.updateUrlParams(buildUrlParams(nextProps.match, nextProps.location, window.location.href));
            }
        }
    }

    render() {
        const {auth, nakedHeader, noNavigationToDashboard,
            componentHeader: ComponentHeader,
            content: Content,
            secondaryHeader: SecondaryHeader,
            bodyClass,
            footer: Footer,
            location: {search}
        } = this.props;
        if (bodyClass && !document.body.className.includes(bodyClass))
            document.body.classList.add(bodyClass);
        const parsed = parse(search);

        return (
            <div>
                <DialogContainer/>
                <Header auth={auth} nakedHeader={nakedHeader} noNavigationToDashboard={noNavigationToDashboard}>
                    {ComponentHeader && <ComponentHeader {...this.props}/>}
                </Header>
                {SecondaryHeader && <SecondaryHeader {...this.props} cameFrom={parsed.cameFrom}/>}
                <Content {...this.props}/>
                {Footer && <Footer/>}
            </div>
        )
    }
}

const mapStateToProps = state => {
    return {
        auth: state.auth.authenticated ? state.auth : null,
        wizard: state.wizardReducer.wizard,
        routing: state.router,
        routingInfo: state.appRouting.routingInfo
    };
};


export default withRouter(connect(mapStateToProps, mapDispatchToProps)(ContentWrapper));


