import classNames from 'classnames';
import React, {Component} from 'react';
import Select from 'react-select';
import Isvg from 'react-inlinesvg';
import ReactPopover from "./../reactPopover/ReactPopover";
import {defaultFilter} from "./../../utils/utils";
import _ from "lodash";
require('./forms.scss');
require("./select.scss");


var magnifyingGlass = require("./../../assets/svgs/magnifying-glass-blue.svg");

const extractError = (error) => _.isArray(error) ? error[0] : error;

export const InputField = (field) => {
    const {className, label, info, children, input, meta: {touched, error}, ...rest} = field;
    const type = field.type ? field.type : "text";
    const classes = classNames({
        'is-invalid-input': touched && extractError(error)
    });

    return (
        <div className={classNames("field-container", className)}>
            {label ?
                <label>{label}
                    {info ? <ReactPopover popoverClass="content-up" contentStyle={{padding: "20px", width: "400px", color: "#d7d7d7"}}
                                          container={<button className="info" type="button"> <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/info-circle-icon.svg")}></Isvg></button>}>
                        {info.text}
                    </ReactPopover> : ""}
                    <input className={classes} type={type}{...input}{...rest}/>
                    {children}
                </label>
                :
                <div>
                    {info ? <ReactPopover popoverClass="content-up" contentStyle={{padding: "20px", width: "400px", color: "#d7d7d7"}}
                                          container={<button className="info" type="button"> <Isvg cacheGetRequests={true} src={require("./../../assets/svgs/info-circle-icon.svg")}></Isvg></button>}>
                        {info.text}
                    </ReactPopover> : ""}
                    <input className={classes} type={type} {...input}{...rest}/>
                    {children}
                </div>

            }
            {touched && extractError(error) && <div className="form-error is-visible" title={extractError(error)}>{extractError(error)}</div>}
        </div>
    )
};

export const RadioInputs = ({className, label, children, inputs, input,checkedIndex,changeSelection, meta: {touched, error}, }) => {
    const classes = classNames({
        'is-invalid-input': touched && extractError(error)
    });

    return (
        <div className="radio-buttons">
            {inputs.map( (item, index) => (
                <div key={index} className={className}>
                    <label>
                        <input className={classes} onClick={() => changeSelection(index)} type="radio" {...input} value={item} checked={input.value === item || checkedIndex === index}/>
                        {item}
                        {children}
                    </label>
                </div>
            ))}
            {touched && extractError(error) && <div className="radio form-error is-visible" title={extractError(error)}>{extractError(error)}</div>}
        </div>
    )
};


export const RadioInputsCustomContent = ({className, contentFunction, inputs, inputId, customCheckboxClass, input,checkedIndex,changeSelection, meta: {touched, error}, }) => {
    const classes = classNames({
        'is-invalid-input': touched && extractError(error)
    });

    const content = inputs.map( (item, index) => {
        var keyValue = inputId ? item[inputId] : item;
        return (<div key={index} className={className}>
            <label>
                <input className={classes} onClick={() => changeSelection(index)} type="radio" {...input}
                       value={keyValue} checked={input.value === keyValue || checkedIndex === index}/>
                {customCheckboxClass && <span className={customCheckboxClass}></span>}
                {contentFunction(item)}
            </label>
        </div>)
    });

    return (
        <div className="radio-buttons-custom-content">
            {content}
            {touched && extractError(error) && <div className="radio form-error is-visible" title={extractError(error)}>{extractError(error)}</div>}
        </div>
    )
};


export class SelectField extends Component{
    static renderOption(option){
        const {title, label, second, third, fourth, disabled} = option;
        return (
            <div title={title} className={classNames("option", {"disabled": disabled})}>
                <span className="first">{label}</span>
                {second && <span className="second">{second}</span>}
                {third && <div><span className="third">{third}</span>{fourth && <span className="fourth">({fourth})</span>}</div>}
            </div>
        )
    }

    render(){
        const {input, meta: {touched, error}, label, extra, options,isLoading, className, noSearch, placeholder, selectedValue} = this.props;
        const classes = classNames({
            'is-invalid-input': touched && extractError(error)
        });
        const style = noSearch ? {} : {backgroundImage: `url(${magnifyingGlass})`};
        const placeholderText = placeholder || "Search...";
        const selectElement = <Select style={style} className={classNames("Select", classes)} classNamePrefix="Select" {...input}
                                      defaultMenuIsOpen={false} //convert to true to debug open select box
                                      onBlurResetsInput={false}
                                      onSelectResetsInput={false}
                                      captureMenuScroll={false}
                                      maxMenuHeight={200}
                                      isSearchable={!noSearch}
                                      isClearable={false}
                                      placeholder={noSearch ? <div></div> : <div><span className="search-text">{placeholderText}</span></div>}
                                      options={options}
                                      value={selectedValue || input.value}
                                      isLoading={isLoading}
                                      filterOption={defaultFilter}
                                      onBlur={(event) => this.props.input.onBlur(event.value)}
                                      onChange={(event) => this.props.input.onChange(event.value)}
        >
            {SelectField.renderOption}
        </Select>;
        return(
            <div className={classNames("field-container", className)}>
                {label ?
                    <label>
                        {label}
                        {selectElement}
                    </label> : selectElement
                }
                {touched && extractError(error) && <div className="Select form-error is-visible">{extractError(error)}<div className="extra float-left">{extra}</div></div>}
            </div>
        );

    }
}

